TReleaseModel class

Constructors

TReleaseModel({required String description, required String version, required String repository, required String changelogUrl, required String readmeUrl, required String coverUrl, required String licenseUrl, required List<TReleaseVersionModel> versions})
TReleaseModel.fromMap(Map<String, dynamic> map)
factory

Properties

changelogUrl String
getter/setter pair
coverUrl String
getter/setter pair
description String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
licenseUrl String
getter/setter pair
readmeUrl String
getter/setter pair
repository String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version String
getter/setter pair
versions List<TReleaseVersionModel>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited