TReleaseVersionModel class

Constructors

TReleaseVersionModel({required String version, required String platform, required String url, required String description, required int date})
TReleaseVersionModel.fromMap(Map<String, dynamic> map)
factory

Properties

date int
getter/setter pair
description String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
platform String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
getter/setter pair
version String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited