TReleaseVersionServices class

Constructors

TReleaseVersionServices()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getLatestVersion(String currentVersion) Future<TReleaseVersionModel?>
getVersionList() Future<List<TReleaseVersionModel>>
isLatestVersion(String currentVersion) Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance TReleaseVersionServices
getter/setter pair