TReleaseWorker class

Constructors

TReleaseWorker()
factory

Properties

currentPath String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
pubspec Map<String, dynamic>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getCoverFileName() String
getRawUrl(String repository, String filePath) String
init() Future<void>
initChangeLog() Future<void>
initReleaseFile() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance TReleaseWorker
getter/setter pair