TReleaseServices class
Constructors
- TReleaseServices()
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getChangeLog(
) → Future< String> -
getDescription(
) → Future< String> -
getLicense(
) → Future< String> -
getReadme(
) → Future< String> -
getRelease(
) → Future< TReleaseModel?> -
getVersion(
) → Future< String> - is only work dev -> production not working!!!
-
initial(
String source) → Future< void> -
source ->
release.jsonpath or release.json url -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ TReleaseServices
-
getter/setter pair